@@ -2,7 +2,7 @@ require 'twitter/arguments'
 require 'twitter/cursor'
 require 'twitter/error'
 require 'twitter/list'
-require 'twitter/request'
+require 'twitter/rest/request'
 require 'twitter/rest/utils'
 require 'twitter/tweet'
 require 'twitter/user'
@@ -40,6 +40,7 @@ module Twitter
       # @see https://dev.twitter.com/docs/api/1.1/get/lists/statuses
       # @rate_limited Yes
       # @authentication Requires user context
+      # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Array<Twitter::Tweet>]
       # @overload list_timeline(list, options = {})
@@ -59,7 +60,7 @@ module Twitter
         arguments = Twitter::Arguments.new(args)
         merge_list!(arguments.options, arguments.pop)
         merge_owner!(arguments.options, arguments.pop)
-        perform_with_objects(:get, '/1.1/lists/statuses.json', arguments.options, Twitter::Tweet)
+        perform_get_with_objects('/1.1/lists/statuses.json', arguments.options, Twitter::Tweet)
       end
 
       # Removes the specified member from the list
@@ -67,6 +68,7 @@ module Twitter
       # @see https://dev.twitter.com/docs/api/1.1/post/lists/members/destroy
       # @rate_limited No
       # @authentication Requires user context
+      # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Twitter::List] The list.
       # @overload remove_list_member(list, user_to_remove, options = {})
@@ -79,7 +81,7 @@ module Twitter
       #   @param user_to_remove [Integer, String] The user id or screen name of the list member to remove.
       #   @param options [Hash] A customizable set of options.
       def remove_list_member(*args)
-        list_from_response_with_user(:post, '/1.1/lists/members/destroy.json', args)
+        list_from_response_with_user('/1.1/lists/members/destroy.json', args)
       end
       deprecate_alias :list_remove_member, :remove_list_member
 
@@ -100,7 +102,7 @@ module Twitter
       #   @option options [Integer] :count The amount of results to return per page. Defaults to 20. No more than 1000 results will ever be returned in a single page.
       #   @option options [Boolean, String, Integer] :filter_to_owned_lists When set to true, t or 1, will return just lists the authenticating user owns, and the user represented by user_id or screen_name is a member of.
       def memberships(*args)
-        cursor_from_response_with_user(:lists, Twitter::List, :get, '/1.1/lists/memberships.json', args)
+        cursor_from_response_with_user(:lists, Twitter::List, '/1.1/lists/memberships.json', args)
       end
 
       # Returns the subscribers of the specified list
@@ -108,6 +110,7 @@ module Twitter
       # @see https://dev.twitter.com/docs/api/1.1/get/lists/subscribers
       # @rate_limited Yes
       # @authentication Requires user context
+      # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Twitter::Cursor] The subscribers of the specified list.
       # @overload list_subscribers(list, options = {})
@@ -118,7 +121,7 @@ module Twitter
       #   @param list [Integer, String, Twitter::List] A Twitter list ID, slug, URI, or object.
       #   @param options [Hash] A customizable set of options.
       def list_subscribers(*args)
-        cursor_from_response_with_list(:get, '/1.1/lists/subscribers.json', args)
+        cursor_from_response_with_list('/1.1/lists/subscribers.json', args)
       end
 
       # Make the authenticated user follow the specified list
@@ -126,6 +129,7 @@ module Twitter
       # @see https://dev.twitter.com/docs/api/1.1/post/lists/subscribers/create
       # @rate_limited No
       # @authentication Requires user context
+      # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Twitter::List] The specified list.
       # @overload list_subscribe(list, options = {})
@@ -144,6 +148,7 @@ module Twitter
       # @see https://dev.twitter.com/docs/api/1.1/get/lists/subscribers/show
       # @rate_limited Yes
       # @authentication Requires user context
+      # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Boolean] true if user is a subscriber of the specified list, otherwise false.
       # @overload list_subscriber?(list, user_to_check, options = {})
@@ -165,6 +170,7 @@ module Twitter
       # @see https://dev.twitter.com/docs/api/1.1/post/lists/subscribers/destroy
       # @rate_limited No
       # @authentication Requires user context
+      # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Twitter::List] The specified list.
       # @overload list_unsubscribe(list, options = {})
@@ -181,9 +187,11 @@ module Twitter
       # Adds specified members to a list
       #
       # @see https://dev.twitter.com/docs/api/1.1/post/lists/members/create_all
-      # @note Lists are limited to having 500 members, and you are limited to adding up to 100 members to a list at a time with this method.
+      # @note Lists are limited to having 5,000 members, and you are limited to adding up to 100 members to a list at a time with this method.
       # @rate_limited No
       # @authentication Requires user context
+      # @raise [Twitter::Error::Forbidden] Error raised when user has already been added.
+      # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Twitter::List] The list.
       # @overload add_list_members(list, users, options = {})
@@ -196,7 +204,7 @@ module Twitter
       #   @param users [Enumerable<Integer, String, Twitter::User>] A collection of Twitter user IDs, screen names, or objects.
       #   @param options [Hash] A customizable set of options.
       def add_list_members(*args)
-        list_from_response_with_users(:post, '/1.1/lists/members/create_all.json', args)
+        list_from_response_with_users('/1.1/lists/members/create_all.json', args)
       end
       deprecate_alias :list_add_members, :add_list_members
 
@@ -205,6 +213,7 @@ module Twitter
       # @see https://dev.twitter.com/docs/api/1.1/get/lists/members/show
       # @authentication Requires user context
       # @rate_limited Yes
+      # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Boolean] true if user is a member of the specified list, otherwise false.
       # @overload list_member?(list, user_to_check, options = {})
@@ -225,6 +234,7 @@ module Twitter
       # @see https://dev.twitter.com/docs/api/1.1/get/lists/members
       # @rate_limited Yes
       # @authentication Requires user context
+      # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Twitter::Cursor]
       # @overload list_members(list, options = {})
@@ -235,15 +245,16 @@ module Twitter
       #   @param list [Integer, String, Twitter::List] A Twitter list ID, slug, URI, or object.
       #   @param options [Hash] A customizable set of options.
       def list_members(*args)
-        cursor_from_response_with_list(:get, '/1.1/lists/members.json', args)
+        cursor_from_response_with_list('/1.1/lists/members.json', args)
       end
 
       # Add a member to a list
       #
       # @see https://dev.twitter.com/docs/api/1.1/post/lists/members/create
-      # @note Lists are limited to having 500 members.
+      # @note Lists are limited to having 5,000 members.
       # @rate_limited No
       # @authentication Requires user context
+      # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Twitter::List] The list.
       # @overload add_list_member(list, user_to_add, options = {})
@@ -256,7 +267,7 @@ module Twitter
       #   @param user_to_add [Integer, String] The user id or screen name to add to the list.
       #   @param options [Hash] A customizable set of options.
       def add_list_member(*args)
-        list_from_response_with_user(:post, '/1.1/lists/members/create.json', args)
+        list_from_response_with_user('/1.1/lists/members/create.json', args)
       end
       deprecate_alias :list_add_member, :add_list_member
 
@@ -266,6 +277,7 @@ module Twitter
       # @note Must be owned by the authenticated user.
       # @rate_limited No
       # @authentication Requires user context
+      # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Twitter::List] The deleted list.
       # @overload destroy_list(list, options = {})
@@ -285,6 +297,7 @@ module Twitter
       # @see https://dev.twitter.com/docs/api/1.1/post/lists/update
       # @rate_limited No
       # @authentication Requires user context
+      # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Twitter::List] The created list.
       # @overload list_update(list, options = {})
@@ -315,7 +328,7 @@ module Twitter
       # @option options [String] :mode ('public') Whether your list is public or private. Values can be 'public' or 'private'.
       # @option options [String] :description The description to give the list.
       def create_list(name, options = {})
-        perform_with_object(:post, '/1.1/lists/create.json', options.merge(:name => name), Twitter::List)
+        perform_post_with_object('/1.1/lists/create.json', options.merge(:name => name), Twitter::List)
       end
       deprecate_alias :list_create, :create_list
 
@@ -325,6 +338,7 @@ module Twitter
       # @note Private lists will only be shown if the authenticated user owns the specified list.
       # @rate_limited Yes
       # @authentication Requires user context
+      # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Twitter::List] The specified list.
       # @overload list(list, options = {})
@@ -351,7 +365,7 @@ module Twitter
       #   @param user [Integer, String, Twitter::User] A Twitter user ID, screen name, URI, or object.
       #   @param options [Hash] A customizable set of options.
       def subscriptions(*args)
-        cursor_from_response_with_user(:lists, Twitter::List, :get, '/1.1/lists/subscriptions.json', args)
+        cursor_from_response_with_user(:lists, Twitter::List, '/1.1/lists/subscriptions.json', args)
       end
 
       # Removes specified members from the list
@@ -359,6 +373,7 @@ module Twitter
       # @see https://dev.twitter.com/docs/api/1.1/post/lists/members/destroy_all
       # @rate_limited No
       # @authentication Requires user context
+      # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Twitter::List] The list.
       # @overload remove_list_members(list, users, options = {})
@@ -371,7 +386,7 @@ module Twitter
       #   @param users [Enumerable<Integer, String, Twitter::User>] A collection of Twitter user IDs, screen names, or objects.
       #   @param options [Hash] A customizable set of options.
       def remove_list_members(*args)
-        list_from_response_with_users(:post, '/1.1/lists/members/destroy_all.json', args)
+        list_from_response_with_users('/1.1/lists/members/destroy_all.json', args)
       end
       deprecate_alias :list_remove_members, :remove_list_members
 
@@ -390,7 +405,7 @@ module Twitter
       #   @param options [Hash] A customizable set of options.
       #   @option options [Integer] :count The amount of results to return per page. Defaults to 20. No more than 1000 results will ever be returned in a single page.
       def owned_lists(*args)
-        cursor_from_response_with_user(:lists, Twitter::List, :get, '/1.1/lists/ownerships.json', args)
+        cursor_from_response_with_user(:lists, Twitter::List, '/1.1/lists/ownerships.json', args)
       end
       deprecate_alias :lists_ownerships, :owned_lists
       deprecate_alias :lists_owned, :owned_lists
@@ -405,14 +420,14 @@ module Twitter
         arguments = Twitter::Arguments.new(args)
         merge_list!(arguments.options, arguments.pop)
         merge_owner!(arguments.options, arguments.pop)
-        perform_with_object(request_method, path, arguments.options, Twitter::List)
+        perform_request_with_object(request_method, path, arguments.options, Twitter::List)
       end
 
-      def cursor_from_response_with_list(request_method, path, args)
+      def cursor_from_response_with_list(path, args)
         arguments = Twitter::Arguments.new(args)
         merge_list!(arguments.options, arguments.pop)
         merge_owner!(arguments.options, arguments.pop)
-        perform_with_cursor(request_method, path, arguments.options, :users, Twitter::User)
+        perform_get_with_cursor(path, arguments.options, :users, Twitter::User)
       end
 
       def list_user?(request_method, path, args)
@@ -420,28 +435,28 @@ module Twitter
         merge_user!(arguments.options, arguments.pop)
         merge_list!(arguments.options, arguments.pop)
         merge_owner!(arguments.options, arguments.pop)
-        send(request_method.to_sym, path, arguments.options)
+        perform_request(request_method.to_sym, path, arguments.options)
         true
-      rescue Twitter::Error::NotFound, Twitter::Error::Forbidden
+      rescue Twitter::Error::Forbidden, Twitter::Error::NotFound
         false
       end
 
-      def list_from_response_with_user(request_method, path, args)
+      def list_from_response_with_user(path, args)
         arguments = Twitter::Arguments.new(args)
         merge_user!(arguments.options, arguments.pop)
         merge_list!(arguments.options, arguments.pop)
         merge_owner!(arguments.options, arguments.pop)
-        perform_with_object(request_method, path, arguments.options, Twitter::List)
+        perform_post_with_object(path, arguments.options, Twitter::List)
       end
 
-      def list_from_response_with_users(request_method, path, args)
+      def list_from_response_with_users(path, args)
         arguments = args.dup
         options = arguments.last.is_a?(::Hash) ? arguments.pop : {}
         members = arguments.pop
         merge_list!(options, arguments.pop)
         merge_owner!(options, arguments.pop)
-        pmap(members.flatten.each_slice(MAX_USERS_PER_REQUEST)) do |users|
-          perform_with_object(request_method, path, merge_users(options, users), Twitter::List)
+        pmap(members.each_slice(MAX_USERS_PER_REQUEST)) do |users|
+          perform_post_with_object(path, merge_users(options, users), Twitter::List)
         end.last
       end
 
