@@ -2,7 +2,7 @@ require 'faraday'
 
 module Twitter
   module REST
-    module Request
+    class Request
       class MultipartWithFile < Faraday::Middleware
         CONTENT_TYPE = 'Content-Type'
         GIF_REGEX = /\.gif$/i
@@ -36,4 +36,4 @@ module Twitter
   end
 end
 
-Faraday::Request.register_middleware :multipart_with_file => Twitter::REST::Request::MultipartWithFile
+Faraday::Request.register_middleware :twitter_multipart_with_file => Twitter::REST::Request::MultipartWithFile
