@@ -1,4 +1,3 @@
-require 'twitter/request'
 require 'twitter/rest/utils'
 require 'twitter/tweet'
 require 'twitter/user'
@@ -24,7 +23,7 @@ module Twitter
       # @option options [Integer] :count Specifies the number of records to retrieve. Must be less than or equal to 200.
       # @option options [Boolean, String, Integer] :trim_user Each tweet returned in a timeline will include a user object with only the author's numerical ID when set to true, 't' or 1.
       def mentions_timeline(options = {})
-        perform_with_objects(:get, '/1.1/statuses/mentions_timeline.json', options, Twitter::Tweet)
+        perform_get_with_objects('/1.1/statuses/mentions_timeline.json', options, Twitter::Tweet)
       end
       alias_method :mentions, :mentions_timeline
 
@@ -111,7 +110,7 @@ module Twitter
       # @option options [Boolean, String, Integer] :include_rts Specifies that the timeline should include native retweets in addition to regular tweets. Note: If you're using the trim_user parameter in conjunction with include_rts, the retweets will no longer contain a full user object.
       # @option options [Boolean, String, Integer] :contributor_details Specifies that the contributors element should be enhanced to include the screen_name of the contributor.
       def home_timeline(options = {})
-        perform_with_objects(:get, '/1.1/statuses/home_timeline.json', options, Twitter::Tweet)
+        perform_get_with_objects('/1.1/statuses/home_timeline.json', options, Twitter::Tweet)
       end
 
       # Returns the 20 most recent retweets posted by users the authenticating user follow.
@@ -149,7 +148,7 @@ module Twitter
       # @option options [Boolean, String, Integer] :trim_user Each tweet returned in a timeline will include a user object with only the author's numerical ID when set to true, 't' or 1.
       # @option options [Boolean, String, Integer] :include_user_entities The user entities node will be disincluded when set to false.
       def retweets_of_me(options = {})
-        perform_with_objects(:get, '/1.1/statuses/retweets_of_me.json', options, Twitter::Tweet)
+        perform_get_with_objects('/1.1/statuses/retweets_of_me.json', options, Twitter::Tweet)
       end
 
     private
