@@ -1,7 +1,7 @@
 require 'twitter/arguments'
 require 'twitter/error'
 require 'twitter/oembed'
-require 'twitter/request'
+require 'twitter/rest/request'
 require 'twitter/rest/utils'
 require 'twitter/tweet'
 require 'twitter/utils'
@@ -25,7 +25,7 @@ module Twitter
       # @option options [Integer] :count Specifies the number of records to retrieve. Must be less than or equal to 100.
       # @option options [Boolean, String, Integer] :trim_user Each tweet returned in a timeline will include a user object with only the author's numerical ID when set to true, 't' or 1.
       def retweets(tweet, options = {})
-        perform_with_objects(:get, "/1.1/statuses/retweets/#{extract_id(tweet)}.json", options, Twitter::Tweet)
+        perform_get_with_objects("/1.1/statuses/retweets/#{extract_id(tweet)}.json", options, Twitter::Tweet)
       end
 
       # Show up to 100 users who retweeted the Tweet
@@ -58,7 +58,7 @@ module Twitter
       # @param options [Hash] A customizable set of options.
       # @option options [Boolean, String, Integer] :trim_user Each tweet returned in a timeline will include a user object with only the author's numerical ID when set to true, 't' or 1.
       def status(tweet, options = {})
-        perform_with_object(:get, "/1.1/statuses/show/#{extract_id(tweet)}.json", options, Twitter::Tweet)
+        perform_get_with_object("/1.1/statuses/show/#{extract_id(tweet)}.json", options, Twitter::Tweet)
       end
 
       # Returns Tweets
@@ -72,13 +72,11 @@ module Twitter
       # @overload statuses(*tweets, options)
       #   @param tweets [Enumerable<Integer, String, URI, Twitter::Tweet>] A collection of Tweet IDs, URIs, or objects.
       #   @param options [Hash] A customizable set of options.
-      #   @option options [Symbol, String] :method Requests users via a GET request instead of the standard POST request if set to ':get'.
       #   @option options [Boolean, String, Integer] :trim_user Each tweet returned in a timeline will include a user object with only the author's numerical ID when set to true, 't' or 1.
       def statuses(*args)
         arguments = Twitter::Arguments.new(args)
-        request_method = arguments.options.delete(:method) || :post
         flat_pmap(arguments.each_slice(MAX_TWEETS_PER_REQUEST)) do |tweets|
-          perform_with_objects(request_method, '/1.1/statuses/lookup.json', arguments.options.merge(:id => tweets.collect { |u| extract_id(u) }.join(',')), Twitter::Tweet)
+          perform_post_with_objects('/1.1/statuses/lookup.json', arguments.options.merge(:id => tweets.collect { |u| extract_id(u) }.join(',')), Twitter::Tweet)
         end
       end
 
@@ -99,7 +97,7 @@ module Twitter
       def destroy_status(*args)
         arguments = Twitter::Arguments.new(args)
         pmap(arguments) do |tweet|
-          perform_with_object(:post, "/1.1/statuses/destroy/#{extract_id(tweet)}.json", arguments.options, Twitter::Tweet)
+          perform_post_with_object("/1.1/statuses/destroy/#{extract_id(tweet)}.json", arguments.options, Twitter::Tweet)
         end
       end
       alias_method :destroy_tweet, :destroy_status
@@ -157,7 +155,7 @@ module Twitter
         hash = options.dup
         hash[:in_reply_to_status_id] = hash.delete(:in_reply_to_status).id unless hash[:in_reply_to_status].nil?
         hash[:place_id] = hash.delete(:place).woeid unless hash[:place].nil?
-        perform_with_object(:post, '/1.1/statuses/update.json', hash.merge(:status => status), Twitter::Tweet)
+        perform_post_with_object('/1.1/statuses/update.json', hash.merge(:status => status), Twitter::Tweet)
       end
 
       # Retweets the specified Tweets as the authenticating user
@@ -178,7 +176,7 @@ module Twitter
         pmap(arguments) do |tweet|
           begin
             post_retweet(extract_id(tweet), arguments.options)
-          rescue Twitter::Error::AlreadyRetweeted
+          rescue Twitter::Error::AlreadyRetweeted, Twitter::Error::NotFound
             next
           end
         end.compact
@@ -190,6 +188,7 @@ module Twitter
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::AlreadyRetweeted] Error raised when tweet has already been retweeted.
+      # @raise [Twitter::Error::NotFound] Error raised when tweet does not exist or has been deleted.
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Array<Twitter::Tweet>] The original tweets with retweet details embedded.
       # @overload retweet!(*tweets)
@@ -231,7 +230,7 @@ module Twitter
         hash = options.dup
         hash[:in_reply_to_status_id] = hash.delete(:in_reply_to_status).id unless hash[:in_reply_to_status].nil?
         hash[:place_id] = hash.delete(:place).woeid unless hash[:place].nil?
-        perform_with_object(:post, '/1.1/statuses/update_with_media.json', hash.merge('media[]' => media, 'status' => status), Twitter::Tweet)
+        perform_post_with_object('/1.1/statuses/update_with_media.json', hash.merge('media[]' => media, 'status' => status), Twitter::Tweet)
       end
 
       # Returns oEmbed for a Tweet
@@ -252,7 +251,7 @@ module Twitter
       # @option options [String] :lang Language code for the rendered embed. This will affect the text and localization of the rendered HTML.
       def oembed(tweet, options = {})
         options[:id] = extract_id(tweet)
-        perform_with_object(:get, '/1.1/statuses/oembed.json', options, Twitter::OEmbed)
+        perform_get_with_object('/1.1/statuses/oembed.json', options, Twitter::OEmbed)
       end
 
       # Returns oEmbeds for Tweets
@@ -296,13 +295,13 @@ module Twitter
       def retweeters_ids(*args)
         arguments = Twitter::Arguments.new(args)
         arguments.options[:id] ||= extract_id(arguments.first)
-        perform_with_cursor(:get, '/1.1/statuses/retweeters/ids.json', arguments.options, :ids)
+        perform_get_with_cursor('/1.1/statuses/retweeters/ids.json', arguments.options, :ids)
       end
 
     private
 
       def post_retweet(tweet, options)
-        response = post("/1.1/statuses/retweet/#{extract_id(tweet)}.json", options).body
+        response = perform_post("/1.1/statuses/retweet/#{extract_id(tweet)}.json", options)
         Twitter::Tweet.new(response)
       end
     end
