@@ -4,7 +4,10 @@ require 'twitter/base'
 module Twitter
   class Suggestion < Twitter::Base
     include Equalizer.new(:slug)
-    attr_reader :name, :size, :slug
+    # @return [Integer]
+    attr_reader :size
+    # @return [String]
+    attr_reader :name, :slug
 
     # @return [Array<Twitter::User>]
     def users
