@@ -6,9 +6,11 @@ module Twitter
   class Tweet < Twitter::Identity
     include Twitter::Creatable
     include Twitter::Entities
-    attr_reader :favorite_count, :filter_level, :in_reply_to_screen_name,
-                :in_reply_to_attrs_id, :in_reply_to_status_id, :in_reply_to_user_id,
-                :lang, :retweet_count, :source, :text
+    # @return [String]
+    attr_reader :filter_level, :in_reply_to_screen_name, :lang, :source, :text
+    # @return [Integer]
+    attr_reader :favorite_count, :in_reply_to_status_id, :in_reply_to_user_id,
+                :retweet_count
     deprecate_alias :favorites_count, :favorite_count
     deprecate_alias :favoriters_count, :favorite_count
     alias_method :in_reply_to_tweet_id, :in_reply_to_status_id
@@ -22,7 +24,8 @@ module Twitter
     alias_method :retweet?, :retweeted_status?
     alias_method :retweeted_tweet?, :retweeted_status?
     object_attr_reader :User, :user, :status
-    predicate_attr_reader :favorited, :retweeted, :truncated
+    predicate_attr_reader :favorited, :possibly_sensitive, :retweeted,
+                          :truncated
 
     # @note May be > 140 characters.
     # @return [String]
@@ -36,9 +39,9 @@ module Twitter
     end
     memoize :full_text
 
-    # @return [String] The URL to the tweet.
+    # @return [Addressable::URI] The URL to the tweet.
     def uri
-      Addressable::URI.parse("https://twitter.com/#{user.screen_name}/status/#{id}") unless user.nil?
+      Addressable::URI.parse("https://twitter.com/#{user.screen_name}/status/#{id}") if user?
     end
     memoize :uri
     alias_method :url, :uri
